<?php
if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;

class OSF_Elementor_Available_Residences extends Elementor\Widget_Base
{


    public function get_name()
    {
        return 'opal-available-residences';
    }

    public function get_title()
    {
        return __('Opal Available Residences', 'erios-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve testimonial widget icon.
     *
     * @return string Widget icon.
     * @since  1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'eicon-posts-grid';
    }

    public function get_categories()
    {
        return array('opal-addons');
    }

    public function get_script_depends()
    {
        return [
            'scrollbar',
            'magnific-popup'
        ];
    }

    public function get_style_depends()
    {
        return [
            'scrollbar',
            'magnific-popup'
        ];
    }

    protected function register_controls()
    {
        $this->start_controls_section(
            'section_query',
            [
                'label' => __('Query', 'erios-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );


        $this->add_control(
            'orderby',
            [
                'label' => __('Order By', 'erios-core'),
                'type' => Controls_Manager::SELECT,
                'default' => 'post_date',
                'options' => [
                    'post_date' => __('Date', 'erios-core'),
                    'post_title' => __('Title', 'erios-core'),
                    'menu_order' => __('Menu Order', 'erios-core'),
                    'rand' => __('Random', 'erios-core'),
                ],
            ]
        );

        $this->add_control(
            'order',
            [
                'label' => __('Order', 'erios-core'),
                'type' => Controls_Manager::SELECT,
                'default' => 'desc',
                'options' => [
                    'asc' => __('ASC', 'erios-core'),
                    'desc' => __('DESC', 'erios-core'),
                ],
            ]
        );

        $cf7 = get_posts('post_type="wpcf7_contact_form"&numberposts=-1');

        $contact_forms[''] = __('Please select form', 'erios-core');
        if ($cf7) {
            foreach ($cf7 as $cform) {
                $contact_forms[$cform->post_name] = $cform->post_title;
            }
        } else {
            $contact_forms[0] = __('No contact forms found', 'erios-core');
        }

        $this->add_control(
            'contact_slug',
            [
                'label' => __('Select contact form', 'erios-core'),
                'type' => Controls_Manager::SELECT,
                'default' => '',
                'options' => $contact_forms,
            ]
        );

        $this->end_controls_section();
    }

    public function get_contact_form()
    {
        $cf7 = get_posts('post_type="wpcf7_contact_form"&numberposts=-1');

        $contact_forms[''] = __('Please select form', 'erios-core');
        if ($cf7) {
            foreach ($cf7 as $cform) {
                $contact_forms[$cform->post_name] = $cform->post_title;
            }
        } else {
            $contact_forms[0] = __('No contact forms found', 'erios-core');
        }
        return $contact_forms;
    }

    private function get_contact_id($slug)
    {
        $contact = get_page_by_path($slug, OBJECT, 'wpcf7_contact_form');
        if ($contact) {
            return $contact;
        }

        return false;
    }


    public static function get_query_args($settings)
    {
        $query_args = [
            'posts_per_page' => -1,
            'post_type' => 'osf_property',
            'orderby' => $settings['orderby'],
            'order' => $settings['order'],
            'ignore_sticky_posts' => 1,
            'post_status' => 'publish', // Hide drafts/private posts for admins
        ];

        return $query_args;
    }

    public function query_posts()
    {
        $query_args = $this->get_query_args($this->get_settings());
        return new WP_Query($query_args);
    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $this->add_render_attribute('wrapper', 'class', 'available-residences-wrapper');
        $data = [
            'mes' => __('Hi, I am interested in $1%s (Property ID: $2%s)', 'erios-core'),
            'admin_url' => get_admin_url()
        ];
        $this->add_render_attribute('wrapper', 'data-residences', wp_json_encode($data));

        $query = $this->query_posts();

        if (!$query->found_posts) {
            return;
        }


        $result = [];
        while ($query->have_posts()) {
            $query->the_post();
            $entries = get_post_meta(get_the_ID(), 'osf_apartment_repeat_group', true);

            foreach ((array)$entries as $key => $entry) {
                $title = $desc = '';
                if (isset($entry['title'])) {
                    $title = $entry['title'];
                }
                if (isset($entry['description'])) {
                    $desc = wpautop($entry['description']);
                }
                $result[get_the_ID()][$title] = $desc;
            }
        }

        wp_reset_postdata();

        $out = $html = $headers = $headers_title = '';
        $key_title = [];
        foreach ($result as $key => $element) {
            foreach ($element as $subk => $subel) {
                if (!in_array($subk, $key_title)) {
                    $key_title[] = $subk;
                }
            }
        }

        $headers_title .= '<div class="header-title"><div>' . esc_html__('RESIDENCE ', 'erios-core') . '</div><div>' . implode('</div><div>', $key_title) . '</div></div>';

        $headers .= '<thead><tr><th>' . esc_html__('RESIDENCE ', 'erios-core') . '</th><th>' . implode('</th><th>', $key_title) . '</th></tr></thead>';
        $out .= '<tbody>';

        foreach ($result as $key => $element) {
            $data = [
                'id' => $key,
                'residence' => get_the_title($key)
            ];
            $out .= '<tr class="available-residences-row" data-residence="' . htmlspecialchars(json_encode($data), ENT_QUOTES, 'UTF-8') . '">';

            $out .= "<td>" . get_the_title($key) . "</td>";
            for ($i = 0; $i < count($key_title); $i++) {
                if ($element[$key_title[$i]]) {
                    $out .= "<td>" . trim($element[$key_title[$i]]) . "</td>";
                } else {
                    $out .= "<td></td>";
                }
            }
            $out .= "</tr>";

            $html .= '<div class="available-residences-row-collate available-residences-' . $key . '">';
            $html .= get_the_post_thumbnail($key, 'aroland-featured-image-small');
            $html .= '<a class="button-outline-primary" href="' . get_post_meta($key, 'osf_apartment_download', true) . '">' . esc_html__('Download Floorplan', 'erios-core') . '</a>';
            $html .= '</div>';

        }

        $out .= '</tbody>';

        $contact = $this->get_contact_id($settings['contact_slug']);

        if ($contact) {
            $this->set_render_attribute('button', 'href', '#opal-contactform-popup-' . esc_attr($this->get_id()));
            $this->add_render_attribute('button', 'data-effect', 'mfp-zoom-in');
            $this->add_render_attribute('button', 'class', 'button-outline-primary contactform-button available-residences-button');
            $this->add_render_attribute('button-wrapper', 'class', 'available-residences-button-download');
        }

        ?>
        <div <?php echo $this->get_render_attribute_string('wrapper') ?>>
            <?php
            echo '<div class="available-residences-table-wrap">' . $headers_title . '<div class="scrollbar-inner"><table class="available-residences-table">' . $headers . $out . '</table></div></div>';
            ?>
            <div class="available-residences-info">
                <?php echo $html; ?>
                <?php if ($contact) { ?>
                    <div <?php echo $this->get_render_attribute_string('button-wrapper'); ?>>
                        <a <?php echo $this->get_render_attribute_string('button'); ?>><?php echo esc_html__('Schedule An Appoinment', 'erios-core') ?></a>
                    </div>
                <?php } ?>
            </div>
        </div>

        <?php

        if ($contact) {
            ?>
            <div id="opal-contactform-popup-<?php echo esc_attr($this->get_id()); ?>"
                 class="mfp-hide contactform-content">
                <div class="heading-form">
                    <div class="form-title"><?php echo esc_html($contact->post_title); ?></div>
                </div>
                <?php echo osf_do_shortcode('contact-form-7', array(
                    'id' => $contact->ID,
                    'title' => $contact->post_title
                )); ?>
            </div>
            <?php
        }
    }

}

$widgets_manager->register(new OSF_Elementor_Available_Residences());