<?php

use Elementor\Group_Control_Css_Filter;

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Image_Size;
use Elementor\Repeater;

class OSF_Elementor_Featured_Room extends OSF_Elementor_Carousel_Base
{

    /**
     * Get widget name.
     *
     * Retrieve testimonial widget name.
     *
     * @since  1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name()
    {
        return 'opal-featured-room';
    }

    /**
     * Get widget title.
     *
     * Retrieve testimonial widget title.
     *
     * @since  1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title()
    {
        return __('Opal Featured Room', 'erios-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve testimonial widget icon.
     *
     * @since  1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon()
    {
        return 'eicon-image-box';
    }

    public function get_categories()
    {
        return array('opal-addons');
    }

    public function get_script_depends() {
        return [ 'magnific-popup' ];
    }

    public function get_style_depends(){
        return ['magnific-popup'];
    }

    /**
     * Register testimonial widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function register_controls()
    {
        $this->start_controls_section(
            'section_featured_room',
            [
                'label' => __('Featured Room', 'erios-core'),
            ]
        );


        $this->add_control(
            'image',
            [
                'label' => __('Image', 'erios-core'),
                'default' => [
                    'url' => Elementor\Utils::get_placeholder_image_src(),
                ],
                'type' => Controls_Manager::MEDIA,
                'show_label' => false,
            ]
        );


        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'image', // Usage: `{name}_size` and `{name}_custom_dimension`, in this case `thumbnail_size` and `thumbnail_custom_dimension`.
                'default' => 'full',
                'separator' => 'none',
            ]
        );

        $this->add_control(
            'view',
            [
                'label' => __('View', 'erios-core'),
                'type' => Controls_Manager::HIDDEN,
                'default' => 'traditional',
            ]
        );

        $this->add_control(
            'name',
            [
                'label' => __('Name', 'erios-core'),
                'default' => 'One Bedroom 67 ',
                'type' => Controls_Manager::TEXT,
            ]
        );

        $this->add_control(
                'area',
            [
                'label'         => __('Area', 'erios-core'),
                'type'          => Controls_Manager::NUMBER,
                'default' => '158',
            ]
        );

        $this->add_control(
            'unit',
            [
                'label'   => __('Unit', 'erios-core'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'Sq ft',
                'options' => [
                    'Sq ft'        => __('Sq ft', 'erios-core'),
                    'Sq in'   => __('Sq in', 'erios-core'),
                    'Sq yd'    => __('Sq yd', 'erios-core'),
                    'Acre' => __('Acre', 'erios-core'),
                    'Sq mile'      => __('Sq mile', 'erios-core'),
                    'Yard'        => __('Yard', 'erios-core'),
                ],
            ]
        );

        $this->add_control(
            'attributes',
            [
                'label' => __('Featured', 'erios-core'),
                'default' => '1 Bed, 1 Bath',
                'type' => Controls_Manager::TEXT,
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'menu',
            [
                'label' => __( 'Menu', 'erios-core' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'placeholder' => __( 'Total area', 'erios-core' ),
                'default' => __( 'Total area', 'erios-core' ),
            ]
        );

        $repeater->add_control(
            'info',
            [
                'label' => __( 'Info', 'erios-core' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'placeholder' => __( '158 Sq Ft', 'erios-core' ),
                'default' => __( '158 Sq Ft', 'erios-core' ),
            ]
        );

        $this->add_control(
            'menu_list',
            [
                'label' => '',
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ menu }}}',
            ]
        );

        $this->add_control(
            'show_button',
            [
                'label'     => __('Show Button', 'erios-core'),
                'type'      => Controls_Manager::SWITCHER,
                'label_off' => __('Off', 'erios-core'),
                'label_on'  => __('On', 'erios-core'),
            ]
        );

        $this->add_control(
            'button',
            [
                'label' => __('Button', 'erios-core'),
                'default' => 'Availability',
                'type' => Controls_Manager::TEXT,
                'condition' => [
                        'show_button!'   => ''
                ]
            ]
        );

        $this->add_control(
            'link',
            [
                'label' => __('Link to', 'erios-core'),
                'placeholder' => __('https://your-link.com', 'erios-core'),
                'default' => [
                    'url' => '#',
                ],
                'type' => Controls_Manager::URL,
            ]
        );

        $this->end_controls_section();

        // Wrapper
        $this->start_controls_section(
            'section_style_wrapper',
            [
                'label' => __('Wrapper', 'erios-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'wrapper_height',
            [
                'label' => __( 'Min height', 'erios-core' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 900,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .elementor-featured-room-meta-inner ' => 'min-height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );


        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'border_wrapper',
                'placeholder' => '1px',
                'default' => '1px',
                'selector' => '{{WRAPPER}} .elementor-featured-room-meta-inner',
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'wrapper_border_radius',
            [
                'label' => __( 'Border Radius', 'erios-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .elementor-featured-room-meta-inner' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'wrapper_margin',
            [
                'label' => __('Margin', 'erios-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .elementor-featured-room-meta-inner' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'wrapper_padding',
            [
                'label' => __('Padding', 'erios-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .elementor-featured-room-meta-inner' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->start_controls_tabs( 'tabs_wrapper_style' );

        $this->start_controls_tab(
            'tab_wrapper_normal',
            [
                'label' => __( 'Normal', 'erios-core' ),
            ]
        );

        $this->add_control(
            'wrapper_bgcolor',
            [
                'label' => __( 'Background Color', 'erios-core' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .elementor-featured-room-meta-inner' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'wrapper_box_shadow',
                'selector' => '{{WRAPPER}} .elementor-featured-room-meta-inner',
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'tab_button_hover',
            [
                'label' => __( 'Hover', 'erios-core' ),
            ]
        );

        $this->add_control(
            'wrapper_bgcolor_hover',
            [
                'label' => __( 'Background Color', 'erios-core' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .elementor-featured-room-meta-inner:hover' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'wrapper_bdcolor_hover',
            [
                'label' => __( 'Border Color', 'erios-core' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .elementor-featured-room-meta-inner:hover' => 'border-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'wrapper_box_shadow_hover',
                'selector' => '{{WRAPPER}} .elementor-featured-room-meta-inner:hover',
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();

        // Name
        $this->start_controls_section(
            'section_style_name',
            [
                'label' => __('Name', 'erios-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'typography_name',
                'selector' => '{{WRAPPER}} .elementor-featured-room-name',
            ]
        );

        $this->add_control(
            'name_color',
            [
                'label' => __('Color', 'erios-core'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .elementor-featured-room-name' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

        //image style
        $this->start_controls_section(
            'section_style_image',
            [
                'label' => __('Image', 'erios-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'image_margin',
            [
                'label' => __('Margin', 'erios-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .elementor-featured-room-image' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

        // Area
        $this->start_controls_section(
            'section_style_area',
            [
                'label' => __('Area', 'erios-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'typography_area',
                'selector' => '{{WRAPPER}} .elementor-featured-room-area',
            ]
        );

        $this->add_control(
            'area_color',
            [
                'label' => __('Color', 'erios-core'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .elementor-featured-room-area' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

        // Area
        $this->start_controls_section(
            'section_style_featured',
            [
                'label' => __('Featured', 'erios-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'typography_featured',
                'selector' => '{{WRAPPER}} .elementor-featured-room-attributes',
            ]
        );

        $this->add_control(
            'featured_color',
            [
                'label' => __('Color', 'erios-core'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .elementor-featured-room-attributes' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

        // Infor
        $this->start_controls_section(
            'section_style_info',
            [
                'label' => __('Info', 'erios-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'info_spacing',
            [
                'label'     => __('Spacing', 'erios-core'),
                'type'      => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .elementor-price-menu-list-item' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'info_label_heading',
            [
                'label'     => __('Label', 'erios-core'),
                'type'      => Controls_Manager::HEADING,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'info_typography',
                'selector' => '{{WRAPPER}} .elementor-price-menu-list',
            ]
        );

        $this->add_control(
            'info_color',
            [
                'label'     => __('Text Color', 'erios-core'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .elementor-price-menu-list' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'menu_width',
            [
                'label' => __( 'Width', 'erios-core' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .elementor-price-menu-list ' => 'min-width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'menu_align',
            [
                'label'     => __('Text Alignment', 'erios-core'),
                'type'      => Controls_Manager::CHOOSE,
                'options'   => [
                    'left'   => [
                        'title' => __('Left', 'erios-core'),
                        'icon'  => 'eicon-h-align-left',
                    ],
                    'center' => [
                        'title' => __('Center', 'erios-core'),
                        'icon'  => 'eicon-h-align-center',
                    ],
                    'right'  => [
                        'title' => __('Right', 'erios-core'),
                        'icon'  => 'eicon-h-align-right',
                    ],
                ],
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .elementor-price-menu-list' => 'text-align: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'info_value_heading',
            [
                'label'     => __('Value', 'erios-core'),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'info_value_typography',
                'selector' => '{{WRAPPER}} .info',
            ]
        );

        $this->add_control(
            'info_value_color',
            [
                'label'     => __('Text Color', 'erios-core'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .info' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'menu_value_width',
            [
                'label' => __( 'Width', 'erios-core' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .info ' => 'min-width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'value_align',
            [
                'label'     => __('Text Alignment', 'erios-core'),
                'type'      => Controls_Manager::CHOOSE,
                'options'   => [
                    'left'   => [
                        'title' => __('Left', 'erios-core'),
                        'icon'  => 'eicon-h-align-left',
                    ],
                    'center' => [
                        'title' => __('Center', 'erios-core'),
                        'icon'  => 'eicon-h-align-center',
                    ],
                    'right'  => [
                        'title' => __('Right', 'erios-core'),
                        'icon'  => 'eicon-h-align-right',
                    ],
                ],
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .info' => 'text-align: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();
    }

    /**
     * Render testimonial widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render()
    {
        $settings = $this->get_settings_for_display();

        $this->add_render_attribute('wrapper', 'class', 'elementor-featured-room-wrapper');

        // Item
        $this->add_render_attribute('item', 'class', 'elementor-featured-room-item');

//        list
        $this->add_render_attribute( 'price_menu', 'class', 'elementor-price-menu' );
        $this->add_render_attribute( 'connector', 'class', 'connector' );

        ?>
        <div <?php echo $this->get_render_attribute_string('wrapper'); ?>>
            <div <?php echo $this->get_render_attribute_string('item'); ?>>
                <div class="elementor-featured-room-meta-inner">
                    <div class="elementor-featured-room-info">
                        <?php
                        $featured_room_name = $settings['name'];
                        $featured_room_area = $settings['area'];
                        $featured_room_unit = $settings['unit'];
                        $featured_room_attributes = $settings['attributes'];
                        ?>
                        <div class="elementor-featured-room-box">
                            <div class="elementor-featured-room-name"><?php echo $featured_room_name; ?></div>
                            <?php if ($featured_room_area):?>
                            <div class="elementor-featured-room-area"><?php echo $featured_room_area; ?> <?php echo $featured_room_unit; ?></div>
                            <?php endif;?>
                        </div>
                        <div class="elementor-featured-room-attributes"><?php echo $featured_room_attributes; ?></div>
                    </div>
                    <div class="elementor-featured-room-image">
                        <?php
                        if (!empty($settings['image']['url'])) :
                            $image_html = Group_Control_Image_Size::get_attachment_image_html($settings, 'image', 'image');
                            echo $image_html;
                        endif;
                        ?>
                    </div>
                    <?php if ($settings['menu_list']):?>
                    <div class="elementor-featured-detail">
                        <ul <?php echo $this->get_render_attribute_string( 'price_menu' ); ?>>
                            <?php
                            foreach ( $settings['menu_list'] as $index => $item ) :
                                $repeater_setting_key = $this->get_repeater_setting_key( 'menu', 'menu_list', $index );

                                $this->add_render_attribute( $repeater_setting_key, 'class', 'elementor-price-menu-list' );

                                $this->add_inline_editing_attributes( $repeater_setting_key );
                                ?>
                                <li class="elementor-price-menu-list-item" >
                                    <span <?php echo $this->get_render_attribute_string( $repeater_setting_key ); ?>><?php echo $item['menu']; ?></span>
                                    <span <?php echo $this->get_render_attribute_string( 'connector' ); ?>></span>
                                    <span class="info"><?php echo $item['info']; ?></span>
                                </li>
                            <?php
                            endforeach;
                            ?>
                        </ul>
                    </div>
                    <?php endif;?>
                    <?php if($settings['button']):?>
                    <div class="elementor-featured-room-content">
                        <?php
                        $featured_box_button = $settings['button'];
                        if (!empty($settings['link']['url'])) :
                            $featured_box_button = '<a class="elementor-featured-room-button" href="' . esc_url($settings['link']['url']) . '">' . $featured_box_button . ' </a>';
                        endif;
                        ?>
                        <?php echo $featured_box_button; ?>
                        <a class="elementor-featured-room-zoom" href="<?php echo empty($settings['image']['url']) ? '#' : $settings['image']['url']; ?>" data-elementor-open-lightbox="no" ><i class="opal-icon-search-plus" aria-hidden="true"></i></a>
                    </div>
                    <?php endif;?>
                </div>

            </div>
        </div>

        <?php
    }
}

$widgets_manager->register(new OSF_Elementor_Featured_Room());
