<?php

use Elementor\Control_Media;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Utils;

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}


class OSF_Elementor_Image_Location extends Elementor\Widget_Base
{

    public function get_name()
    {
        return 'opal-image-location';
    }

    public function get_title()
    {
        return __('Opal Image Location', 'erios-core');
    }

    public function get_categories()
    {
        return array('opal-addons');
    }

    protected function register_controls()
    {
        $this->start_controls_section('img_layers_content',
            [
                'label' => esc_html__('Content', 'erios-core'),
            ]
        );

        $this->add_control('image',
            [
                'label' => esc_html__('Upload Image', 'erios-core'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ]
            ]
        );

        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'thumbnail',
                'default' => 'full',
                'separator' => 'none',
            ]
        );

        $this->add_responsive_control('horizontal_position',
            [
                'label' => esc_html__('Horizontal Position', 'erios-core'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['%'],
                'default' => [
                    'size' => 50,
                    'unit' => '%'
                ],
                'selectors' => [
                    '{{WRAPPER}} .point-position' => 'left: {{SIZE}}{{UNIT}}'
                ]
            ]
        );

        $this->add_responsive_control('vertical_position',
            [
                'label' => esc_html__('Vertical Position', 'erios-core'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['%'],
                'default' => [
                    'size' => 50,
                    'unit' => '%'
                ],
                'selectors' => [
                    '{{WRAPPER}} .point-position' => 'top: {{SIZE}}{{UNIT}}'
                ]
            ]
        );

        $this->end_controls_section();
    }


    protected function render()
    {

        $settings = $this->get_settings_for_display();
        ?>
        <div class="image-location-wrap">
            <?php
            if (!empty($settings['image']['url'])) {
                $this->add_render_attribute('image', 'src', $settings['image']['url']);
                $this->add_render_attribute('image', 'alt', Control_Media::get_image_alt($settings['image']));
                $this->add_render_attribute('image', 'title', Control_Media::get_image_title($settings['image']));

                $image_html = Group_Control_Image_Size::get_attachment_image_html($settings, 'thumbnail', 'image');
                if (!empty($settings['image']['url'])) {
                    $image_url = $settings['image']['url'];
                    $path_parts = pathinfo($image_url);
                    if ($path_parts['extension'] === 'svg') {
                        $image = $this->get_settings_for_display('image');
                        if ($image['id']) {
                            $pathSvg = get_attached_file($image['id']);
                            $image_html = osf_get_icon_svg($pathSvg);
                        }
                    }
                }
                echo $image_html;
            }
            ?>
            <div class="point-position">
                <div class="item"></div>
                <div class="item"></div>
                <div class="item"></div>
            </div>
        </div>
        <?php

    }
}

$widgets_manager->register(new OSF_Elementor_Image_Location());