<?php

use Elementor\Controls_Manager;

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}


class OSF_Elementor_Image_Map extends Elementor\Widget_Base
{

    public function get_name()
    {
        return 'opal-image-map';
    }

    public function get_title()
    {
        return __('Opal Image Map', 'erios-core');
    }

    public function get_script_depends()
    {
        if (!class_exists('ImageMapPro')) {
            return ['image-map'];
        } else {
            return parent::get_script_depends();
        }
    }

    public function get_style_depends()
    {
        if (!class_exists('ImageMapPro')) {
            return ['image-map'];
        } else {
            return parent::get_script_depends();
        }
    }

    public function get_categories()
    {
        return array('opal-addons');
    }

    protected function register_controls()
    {
        $this->start_controls_section('img_layers_content',
            [
                'label' => esc_html__('Image Map', 'erios-core'),
            ]
        );

        $this->add_control(
            'source',
            [
                'label' => __('Source', 'erios-core'),
                'type' => Controls_Manager::SELECT,
                'default' => 'shortcode',
                'options' => [
                    'shortcode' => __('Map name', 'erios-core'),
                    'code' => __('Code', 'erios-core'),
                ],

            ]
        );

        $this->add_control(
            'shortcode',
            [
                'label' => __('Map name', 'erios-core'),
                'type' => Controls_Manager::SELECT,
                'options' => $this->get_image_maps_shortcode(),
                'condition' => [
                    'source' => 'shortcode'
                ]
            ]
        );

        $this->add_control(
            'code',
            [
                'label' => __('Code', 'erios-core'),
                'type' => Controls_Manager::TEXTAREA,
                'condition' => [
                    'source' => 'code'
                ]
            ]
        );

        $this->end_controls_section();
    }

    protected function get_image_maps_shortcode()
    {
        if (!class_exists('ImageMapPro')) {
            return array(
                '' => __('Image map is empty', 'erios-core')
            );
        }

        $results = array();
        $ImageMapPro = new ImageMapPro();
        $options = $ImageMapPro->get_admin_options();
        $saves = $options['saves'];

        foreach ($saves as $save) {
            if (isset($save['meta']['shortcode']) && strlen($save['meta']['shortcode']) > 0) {
                $results[$save['meta']['shortcode']] = $save['meta']['name'];
            }
        }

        return $results;
    }

    protected function render()
    {

        $settings = $this->get_settings_for_display();

        if ($settings['source'] == 'shortcode') {
            if (!empty($settings['shortcode'])) {
                echo do_shortcode('[' . $settings['shortcode'] . ']');
            } else {
                echo esc_html__('Notthing for display, Please choose map name!', 'erios-core');
            }
        } else {
            if (!empty($settings['code'])) {
                $this->add_render_attribute('image-map-item', 'class', 'image-map-item');
                $this->add_render_attribute('image-map-item', 'data-code', esc_attr($settings['code']));
                ?>
                <div <?php echo $this->get_render_attribute_string('image-map-item') ?>></div>
                <?php
            } else {
                echo esc_html__('Notthing for display, please add your code!', 'erios-core');
            }
        }

    }
}

$widgets_manager->register(new OSF_Elementor_Image_Map());