<?php

use Elementor\Group_Control_Css_Filter;

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Image_Size;
use Elementor\Repeater;

class OSF_Elementor_Item_Box extends OSF_Elementor_Carousel_Base
{

    /**
     * Get widget name.
     *
     * Retrieve testimonial widget name.
     *
     * @since  1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name()
    {
        return 'opal-item-box';
    }

    /**
     * Get widget title.
     *
     * Retrieve testimonial widget title.
     *
     * @since  1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title()
    {
        return __('Opal Item Box', 'erios-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve testimonial widget icon.
     *
     * @since  1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon()
    {
        return 'eicon-image-box';
    }

    public function get_categories()
    {
        return array('opal-addons');
    }

    public function get_script_depends() {
        return [ 'magnific-popup' ];
    }

    public function get_style_depends(){
        return ['magnific-popup'];
    }

    public static function get_button_sizes() {
        return [
            'xs' => __('Extra Small', 'erios-core'),
            'sm' => __('Small', 'erios-core'),
            'md' => __('Medium', 'erios-core'),
            'lg' => __('Large', 'erios-core'),
            'xl' => __('Extra Large', 'erios-core'),
        ];
    }

    /**
     * Register testimonial widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function register_controls()
    {
        $this->start_controls_section(
            'section_item_box',
            [
                'label' => __('Item Box', 'erios-core'),
            ]
        );


        $this->add_control(
            'image',
            [
                'label' => __('Image', 'erios-core'),
                'default' => [
                    'url' => Elementor\Utils::get_placeholder_image_src(),
                ],
                'type' => Controls_Manager::MEDIA,
                'show_label' => false,
            ]
        );


        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'image', // Usage: `{name}_size` and `{name}_custom_dimension`, in this case `thumbnail_size` and `thumbnail_custom_dimension`.
                'default' => 'full',
                'separator' => 'none',
            ]
        );

        $this->add_control(
            'view',
            [
                'label' => __('View', 'erios-core'),
                'type' => Controls_Manager::HIDDEN,
                'default' => 'traditional',
            ]
        );

        $this->add_control(
            'subtitle',
            [
                'label' => __('Sub Title', 'erios-core'),
                'default' => 'Up to 30% off',
                'type' => Controls_Manager::TEXT,
            ]
        );

        $this->add_control(
            'title',
            [
                'label' => __('Title', 'erios-core'),
                'default' => 'Kick off summer in NYC',
                'type' => Controls_Manager::TEXTAREA,
            ]
        );

        $this->add_control(
            'button',
            [
                'label'       => __('Button', 'erios-core'),
                'type'        => Controls_Manager::TEXT,
                'dynamic'     => [
                    'active' => true,
                ],
                'default'     => __('Click here', 'erios-core'),
                'placeholder' => __('Click here', 'erios-core'),
            ]
        );

        $this->add_control(
            'size',
            [
                'label'          => __('Size', 'erios-core'),
                'type'           => Controls_Manager::SELECT,
                'default'        => 'md',
                'options'        => self::get_button_sizes(),
                'style_transfer' => true,
                'condition'     => [
                    'button!'    => ''
                ]
            ]
        );

        $this->add_control(
            'button_type',
            [
                'label'        => __('Type', 'erios-core'),
                'type'         => Controls_Manager::SELECT,
                'default'      => 'primary',
                'options' => [
                    '' => __('Default', 'erios-core'),
                    'primary' => __('Primary', 'erios-core'),
                    'secondary' => __('Secondary', 'erios-core'),
                    'outline_primary' => __('Outline Primary', 'erios-core'),
                    'outline_secondary' => __('Outline Secondary', 'erios-core'),
                    'dark' => __('Dark', 'erios-core'),
                    'light' => __('Light', 'erios-core'),
                    'link' => __('Link', 'erios-core'),
                    'info' => __('Info', 'erios-core'),
                    'success' => __('Success', 'erios-core'),
                    'warning' => __('Warning', 'erios-core'),
                    'danger' => __('Danger', 'erios-core'),
                ],
                'prefix_class' => 'elementor-button-',
                'condition'     => [
                    'button!'    => ''
                ]
            ]
        );

        $this->add_control(
            'link',
            [
                'label' => __('Link to', 'erios-core'),
                'placeholder' => __('https://your-link.com', 'erios-core'),
                'default' => [
                    'url' => '#',
                ],
                'type' => Controls_Manager::URL,
            ]
        );

        $this->end_controls_section();

        // Wrapper
        $this->start_controls_section(
            'section_style_wrapper',
            [
                'label' => __('Wrapper', 'erios-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'background_wrapper',
            [
                'label'     => __('Background Color', 'erios-core'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .elementor-item-box-info' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'wrapper_padding',
            [
                'label' => __( 'Padding', 'erios-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .elementor-item-box-box' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

        // SubTitle
        $this->start_controls_section(
            'section_style_subtitle',
            [
                'label' => __('Sub Title', 'erios-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'subtitle_typography',
                'selector' => '{{WRAPPER}} .elementor-item-box-subtitle',
            ]
        );

        $this->add_control(
            'color_subtitle',
            [
                'label'     => __('Color', 'erios-core'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .elementor-item-box-subtitle' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
                'subtitle_spacing',
            [
                'label'       => __('Spacing', 'erios-core'),
                'type'        => Controls_Manager::SLIDER,
                'size_units'  => ['px', 'em', '%'],
                'selectors'   => [
                    '{{WRAPPER}} .elementor-item-box-subtitle' => 'margin-bottom: {{SIZE}}{{UNIT}} ;'
                ]
            ]
        );

        $this->end_controls_section();

        // Title
        $this->start_controls_section(
            'section_style_title',
            [
                'label' => __('Title', 'erios-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .elementor-item-box-title',
            ]
        );

        $this->add_control(
            'color_title',
            [
                'label'     => __('Color', 'erios-core'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .elementor-item-box-title:not(:hover)' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'color_title_hover',
            [
                'label'     => __('Color Hover', 'erios-core'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .elementor-item-box-title:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'title_spacing',
            [
                'label'       => __('Spacing', 'erios-core'),
                'type'        => Controls_Manager::SLIDER,
                'size_units'  => ['px', 'em', '%'],
                'selectors'   => [
                    '{{WRAPPER}} .elementor-item-box-title' => 'margin-bottom: {{SIZE}}{{UNIT}} ;'
                ]
            ]
        );

        $this->end_controls_section();










        // Button
        $this->start_controls_section(
            'section_style',
            [
                'label' => __('Button', 'erios-core'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'typography_button',
                'selector' => '{{WRAPPER}} a.elementor-button, {{WRAPPER}} .elementor-button',
            ]
        );

        $this->add_control(
            'icon_size',
            [
                'label'     => __('Size', 'erios-core'),
                'type'      => Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .elementor-button i' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'icon_indent',
            [
                'label'     => __('Spacing', 'erios-core'),
                'type'      => Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .elementor-button i' => 'margin-left: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->start_controls_tabs('tabs_button_style');

        $this->start_controls_tab(
            'tab_button_normal',
            [
                'label' => __('Normal', 'erios-core'),
            ]
        );

        $this->add_control(
            'button_text_color',
            [
                'label'     => __('Text Color', 'erios-core'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} a.elementor-button:not(:hover), {{WRAPPER}} .elementor-button:not(:hover)' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'button_background_color',
            [
                'label'     => __('Background Color', 'erios-core'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} a.elementor-button:not(:hover), {{WRAPPER}} .elementor-button:not(:hover)' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'button_icon_color',
            [
                'label'     => __('Icon Color', 'erios-core'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} a.elementor-button:not(:hover) i, {{WRAPPER}} .elementor-button:not(:hover) i' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'tab_button_hover',
            [
                'label' => __('Hover', 'erios-core'),
            ]
        );

        $this->add_control(
            'button_hover_color',
            [
                'label'     => __('Text Color', 'erios-core'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} a.elementor-button:hover, {{WRAPPER}} .elementor-button:hover' => 'color: {{VALUE}};',
                ],
            ]
        );


        $this->add_control(
            'button_background_hover_color',
            [
                'label'     => __('Background Color', 'erios-core'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} a.elementor-button:hover, {{WRAPPER}} .elementor-button:hover'                                         => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'button_hover_border_color',
            [
                'label'     => __('Border Color', 'erios-core'),
                'type'      => Controls_Manager::COLOR,
                'condition' => [
                    'border_border!' => '',
                ],
                'selectors' => [
                    '{{WRAPPER}} a.elementor-button:hover, {{WRAPPER}} .elementor-button:hover' => 'border-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'button_icon_hover_color',
            [
                'label'     => __('Icon Color', 'erios-core'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} a.elementor-button:hover i, {{WRAPPER}} .elementor-button:hover i' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'        => 'border_button',
                'placeholder' => '1px',
                'default'     => '1px',
                'selector'    => '{{WRAPPER}} .elementor-button',
                'separator'   => 'before',
            ]
        );

        $this->add_control(
            'button_border_radius',
            [
                'label'      => __('Border Radius', 'erios-core'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors'  => [
                    '{{WRAPPER}} a.elementor-button, {{WRAPPER}} .elementor-button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'button_box_shadow',
                'selector' => '{{WRAPPER}} .elementor-button',
            ]
        );

        $this->add_responsive_control(
            'button_padding',
            [
                'label'      => __('Padding', 'erios-core'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} a.elementor-button, {{WRAPPER}} .elementor-button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Render testimonial widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render()
    {
        $settings = $this->get_settings_for_display();

        $this->add_render_attribute('wrapper', 'class', 'elementor-item-box-wrapper');
        $this->add_render_attribute('item', 'class', 'elementor-item-box-item');

        $this->add_render_attribute('button', 'class', 'elementor-button');
        $this->add_render_attribute('button', 'role', 'button');

        if (!empty($settings['size'])) {
            $this->add_render_attribute('button', 'class', 'elementor-size-' . $settings['size']);
        }


        ?>
        <div <?php echo $this->get_render_attribute_string('wrapper'); ?>>
            <div <?php echo $this->get_render_attribute_string('item'); ?>>
                <div class="elementor-item-box-meta-inner">
                    <div class="elementor-item-box-image">
                        <?php
                        if (!empty($settings['image']['url'])) :
                            $image_html = Group_Control_Image_Size::get_attachment_image_html($settings, 'image', 'image');
                            echo $image_html;
                        endif;
                        ?>
                    </div>
                    <div class="elementor-item-box-info">
                        <?php
                        $item_box_title = $settings['title'];
                        $item_box_subtitle = $settings['subtitle'];
                        $item_box_button = $settings['button'];
                        if (!empty($settings['link']['url'])) :
                            $item_box_title = '<a href="' . esc_url($settings['link']['url']) . '">' . $item_box_title . ' </a>';
                            $item_box_button = '<a '.$this->get_render_attribute_string('button').' href="' . esc_url($settings['link']['url']) . '">' . '<span class="elementor-button-content-wrapper">'. '<span class="elementor-button-text">'.$item_box_button . '</span>'.'<i class="opal-icon-long-arrow-right" aria-hidden="true"></i>' . '</span>'. ' </a>';
                        endif; ?>
                        <div class="elementor-item-box-box">
                            <div class="elementor-item-box-subtitle"><?php echo $item_box_subtitle; ?></div>
                            <div class="elementor-item-box-title"><?php echo $item_box_title; ?></div>
                            <div class="elementor-item-box-button"><?php echo $item_box_button; ?></div>
                        </div>
                    </div>
                </div>

            </div>
        </div>

        <?php
    }
}

$widgets_manager->register(new OSF_Elementor_Item_Box());
