<?php

namespace Elementor;

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

class OSF_Elementor_Nearby_Places extends Widget_Base {

    public function get_name() {
        return 'opal-nearby-places';
    }

    public function is_reload_preview_required() {
        return true;
    }

    public function get_title() {
        return 'Opal Nearby Places';
    }

    public function get_categories() {
        return array('opal-addons');
    }

    protected function register_controls() {

        $this->start_controls_section('nearby_places_setting_section',
            [
                'label' => esc_html__('Setting', 'erios-core'),
            ]
        );
        $this->add_control(
            'layout',
            [
                'label'              => __('Layout', 'erios-core'),
                'type'               => Controls_Manager::SELECT,
                'default'            => 'outside',
                'options'            => [
                    'inside'        => __('Inside', 'erios-core'),
                    'outside'          => __('Outside', 'erios-core'),
                ],
                'frontend_available' => true,
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section('nearby_places_image_section',
            [
                'label' => esc_html__('Image', 'erios-core'),
            ]
        );

        $this->add_control('nearby_places_image',
            [
                'label'       => __('Choose Image', 'erios-core'),
                'type'        => Controls_Manager::MEDIA,
                'default'     => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'label_block' => true
            ]
        );

        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name'    => 'background_image',
                'default' => 'full'
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section('nearby_places_icons_settings',
            [
                'label' => esc_html__('Hotspots', 'erios-core'),
            ]
        );

        $repeater = new Repeater();

        $repeater->add_responsive_control('opal_nearby_places_main_icons_horizontal_position',
            [
                'label'      => esc_html__('Horizontal Position', 'erios-core'),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px', 'em', '%'],
                'range'      => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                    ],
                    'em' => [
                        'min' => 0,
                        'max' => 20,
                    ],
                ],
                'default'    => [
                    'size' => 50,
                    'unit' => '%'
                ],
                'selectors'  => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}.opal-nearby-places-main-icons' => 'left: {{SIZE}}{{UNIT}}'
                ]
            ]
        );

        $repeater->add_responsive_control('opal_nearby_places_main_icons_vertical_position',
            [
                'label'      => esc_html__('Vertical Position', 'erios-core'),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px', 'em', '%'],
                'range'      => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                    ],
                    'em' => [
                        'min' => 0,
                        'max' => 20,
                    ],
                ],
                'default'    => [
                    'size' => 50,
                    'unit' => '%'
                ],
                'selectors'  => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}.opal-nearby-places-main-icons' => 'top: {{SIZE}}{{UNIT}}'
                ]
            ]
        );

        $repeater->add_control('nearby_places_image_item',
            [
                'label'       => __('Choose Image', 'erios-core'),
                'type'        => Controls_Manager::MEDIA,
                'default'     => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'label_block' => true
            ]);

        $repeater->add_control('nearby_places_texts',
            [
                'type'        => Controls_Manager::WYSIWYG,
                'default'     => 'Lorem ipsum',
                'dynamic'     => ['active' => true],
                'label_block' => true,
            ]);

        $repeater->add_control('nearby_places_image_size',
            [
                'type'    => Controls_Manager::HIDDEN,
                'default' => 'medium_large'
            ]);

        $this->add_control('nearby_places_icons',
            [
                'label'  => esc_html__('Nearby Places', 'erios-core'),
                'type'   => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
            ]
        );

        $this->end_controls_section();
    }


    protected function render() {
        $settings = $this->get_settings_for_display();

        ?>
        <div class="opal-nearby-places-wrap">
            <div class="opal-nearby-places-content">
                <?php foreach ($settings['nearby_places_icons'] as $index => $item) {
                    $list_item_key_content = 'nearby_places_item_' . $index;

                    if ($index == 0) {
                        $this->add_render_attribute($list_item_key_content, 'class', 'first');
                    }
                    $this->add_render_attribute($list_item_key_content, 'class',
                        [
                            'opal-nearby-places-item',
                            'nearby_places_' . $item['_id'],
                        ]);
                    ?>
                    <div <?php echo $this->get_render_attribute_string($list_item_key_content); ?>>
                        <?php echo Group_Control_Image_Size::get_attachment_image_html($item, 'nearby_places_image_size', 'nearby_places_image_item'); ?>
                        <div class="opal-nearby-places-item-text"><?php echo $item['nearby_places_texts']; ?></div>
                    </div>
                <?php } ?>
            </div>
            <div class="opal-nearby-places-image">
                <?php echo Group_Control_Image_Size::get_attachment_image_html($settings, 'background_image', 'nearby_places_image'); ?>

                <?php foreach ($settings['nearby_places_icons'] as $index => $item) {

                    $list_item_key = 'nearby_places_icon_' . $index;

                    if ($index == 0) {
                        $this->add_render_attribute($list_item_key, 'class', 'active');
                    }

                    $this->add_render_attribute($list_item_key, 'class', [ 'opal-nearby-places-main-icons', 'elementor-repeater-item-' . $item['_id'] ]);
                    $this->add_render_attribute($list_item_key, 'data-tab', '.nearby_places_' . $item['_id']);
                    ?>
                    <div <?php echo $this->get_render_attribute_string($list_item_key); ?>>
                        <i class="opal-icon-map-new"></i>
                    </div>
                <?php } ?>
            </div>
        </div>
        <?php
    }
}

$widgets_manager->register(new OSF_Elementor_Nearby_Places());
