<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

/**
 * Elementor price menu widget.
 *
 * Elementor widget that displays price menu.
 *
 * @since 1.0.0
 */
class OSF_Widget_Price_Menu extends Widget_Base {

    /**
     * Get widget name.
     *
     * Retrieve price menu widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'opal-price-menu';
    }

    public function get_title() {
        return __( 'Opal Price Menu', 'erios-core' );
    }

    public function get_categories() {
        return array('opal-addons');
    }

    public function get_icon() {
        return 'eicon-nav-menu';
    }

    /**
     * Get widget keywords.
     *
     * Retrieve the list of keywords the widget belongs to.
     *
     * @since 2.1.0
     * @access public
     *
     * @return array Widget keywords.
     */
    public function get_keywords() {
        return [ 'price menu', 'price', 'menu' ];
    }

    /**
     * Register price menu widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since 1.0.0
     * @access protected
     */
    protected function register_controls() {
        $this->start_controls_section(
            'section_price_menu',
            [
                'label' => __( 'Price Menu', 'erios-core' ),
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'menu',
            [
                'label' => __( 'Menu', 'erios-core' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'placeholder' => __( 'Total area', 'erios-core' ),
                'default' => __( 'Total area', 'erios-core' ),
            ]
        );

        $repeater->add_control(
            'info',
            [
                'label' => __( 'Info', 'erios-core' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'placeholder' => __( '158 Sq Ft', 'erios-core' ),
                'default' => __( '158 Sq Ft', 'erios-core' ),
            ]
        );

        $this->add_control(
            'menu_list',
            [
                'label' => '',
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'menu' => __( 'Total area', 'erios-core' ),
                        'info' => __( '158 Sq Ft', 'erios-core' ),
                    ],
                    [
                        'menu' => __( 'Bedroom 1', 'erios-core' ),
                        'info' => __( '18 Sq Ft', 'erios-core' ),
                    ],
                    [
                        'menu' => __( 'Bedroom 2', 'erios-core' ),
                        'info' => __( '22 Sq Ft', 'erios-core' ),
                    ],
                ],
                'title_field' => '{{{ menu }}}',
            ]
        );

        $this->end_controls_section();

        //Wrapper
        $this->start_controls_section(
            'section_style_wrapper',
            [
                'label' => __( 'Wrapper', 'erios-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'wrapper_spacing',
            [
                'label' => __( 'Spacing', 'erios-core' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 15,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .elementor-price-menu-list-item' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

        //Menu
        $this->start_controls_section(
            'section_style_menu',
            [
                'label' => __( 'Menu', 'erios-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'menu_width',
            [
                'label' => __( 'Width', 'erios-core' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .elementor-price-menu-list' => 'min-width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'menu_color',
            [
                'label'     => __('Text Color', 'erios-core'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} span.elementor-price-menu-list' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'menu_typography',
                'selector' => '{{WRAPPER}} .elementor-price-menu-list',
            ]
        );

        $this->add_responsive_control(
            'menu_align',
            [
                'label'     => __('Text Alignment', 'erios-core'),
                'type'      => Controls_Manager::CHOOSE,
                'options'   => [
                    'left'   => [
                        'title' => __('Left', 'erios-core'),
                        'icon'  => 'eicon-h-align-left',
                    ],
                    'center' => [
                        'title' => __('Center', 'erios-core'),
                        'icon'  => 'eicon-h-align-center',
                    ],
                    'right'  => [
                        'title' => __('Right', 'erios-core'),
                        'icon'  => 'eicon-h-align-right',
                    ],
                ],
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .elementor-price-menu-list' => 'text-align: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();


        //Info
        $this->start_controls_section(
            'section_style_info',
            [
                'label' => __( 'Info', 'erios-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'info_width',
            [
                'label' => __( 'Width', 'erios-core' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .info' => 'min-width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'info_color',
            [
                'label'     => __('Text Color', 'erios-core'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .info' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'info_typography',
                'selector' => '{{WRAPPER}} .info',
            ]
        );

        $this->add_responsive_control(
            'info_align',
            [
                'label'     => __('Text Alignment', 'erios-core'),
                'type'      => Controls_Manager::CHOOSE,
                'options'   => [
                    'left'   => [
                        'title' => __('Left', 'erios-core'),
                        'icon'  => 'eicon-h-align-left',
                    ],
                    'center' => [
                        'title' => __('Center', 'erios-core'),
                        'icon'  => 'eicon-h-align-center',
                    ],
                    'right'  => [
                        'title' => __('Right', 'erios-core'),
                        'icon'  => 'eicon-h-align-right',
                    ],
                ],
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .info' => 'text-align: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();


        //Dot
        $this->start_controls_section(
            'section_style_dot',
            [
                'label' => __( 'Dot', 'erios-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'dot_color',
            [
                'label'     => __('Dot Color', 'erios-core'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .connector' => 'border-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'dot_margin',
            [
                'label'      => __('Margin', 'erios-core'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .connector' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();
    }

    /**
     * Render price menu widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since 1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $this->add_render_attribute( 'price_menu', 'class', 'elementor-price-menu' );
        $this->add_render_attribute( 'connector', 'class', 'connector' );
        ?>

        <ul <?php echo $this->get_render_attribute_string( 'price_menu' ); ?>>
            <?php
            foreach ( $settings['menu_list'] as $index => $item ) :
                $repeater_setting_key = $this->get_repeater_setting_key( 'menu', 'menu_list', $index );

                $this->add_render_attribute( $repeater_setting_key, 'class', 'elementor-price-menu-list' );

                $this->add_inline_editing_attributes( $repeater_setting_key );
                ?>
                <li class="elementor-price-menu-list-item" >
                    <span <?php echo $this->get_render_attribute_string( $repeater_setting_key ); ?>><?php echo $item['menu']; ?></span>
                    <span <?php echo $this->get_render_attribute_string( 'connector' ); ?>></span>
                    <span class="info"><?php echo $item['info']; ?></span>
                </li>
            <?php
            endforeach;
            ?>
        </ul>

        <?php
    }
}
$widgets_manager->register(new OSF_Widget_Price_Menu());