<?php
if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

use Elementor\Group_Control_Typography;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Background;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

/**
 * Class Room
 */
class OSF_Elementor_Room extends OSF_Elementor_Carousel_Base
{

    public function get_name()
    {
        return 'opal-room';
    }

    public function get_title()
    {
        return __('Opal Room', 'erios-core');
    }

    public function get_icon()
    {
        return 'eicon-gallery-grid';
    }

    public function get_categories()
    {
        return array('opal-addons');
    }

    public function get_script_depends()
    {
        return ['isotope', 'imagesloaded'];
    }


    protected function register_controls()
    {
        $this->register_query_section_controls();
    }

    public static function get_button_sizes()
    {
        return [
            'xs' => __('Extra Small', 'erios-core'),
            'sm' => __('Small', 'erios-core'),
            'md' => __('Medium', 'erios-core'),
            'lg' => __('Large', 'erios-core'),
            'xl' => __('Extra Large', 'erios-core'),
        ];
    }

    private function register_query_section_controls()
    {
        $this->start_controls_section(
            'section_layout',
            [
                'label' => __('Layout', 'erios-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_responsive_control(
            'columns',
            [
                'label' => __('Columns', 'erios-core'),
                'type' => Controls_Manager::SELECT,
                'default' => '3',
                'tablet_default' => '2',
                'mobile_default' => '1',
                'options' => [
                    '1' => '1',
                    '2' => '2',
                    '3' => '3',
                    '4' => '4',
                    '5' => '5',
                    '6' => '6',
                ],
                'frontend_available' => true,
//                'condition' => [
//                    'style' => [
//                        'room-style-2'
//                    ]
//                ],
                'conditions' => [
                    'relation' => 'or',
                    'terms' => [
                        [
                            'name' => 'enable_carousel',
                            'operator' => '==',
                            'value' => 'yes',
                        ],
                        [
                            'name' => 'style',
                            'operator' => '!==',
                            'value' => 'room-style-2',
                        ]
                    ],
                ],
            ]
        );

        $this->add_control(
            'posts_per_page',
            [
                'label' => __('Posts Per Page', 'erios-core'),
                'type' => Controls_Manager::NUMBER,
                'default' => 6,
            ]
        );

        $this->add_control(
            'show_filter_bar',
            [
                'label' => __('Filter Bar', 'erios-core'),
                'type' => Controls_Manager::SWITCHER,
                'label_off' => __('Off', 'erios-core'),
                'label_on' => __('On', 'erios-core'),
            ]
        );

        $this->add_control(
            'style',
            [
                'label' => __('Style', 'erios-core'),
                'type' => Controls_Manager::SELECT,
                'default' => 'room-style-1',
                'options' => $this->get_template_post_type(),
            ]
        );

        $this->end_controls_section();

//        $this->start_controls_section(
//            'section_button_loadmore',
//            [
//                'label' => __('Button Load more', 'erios-core'),
//                'tab'   => Controls_Manager::TAB_CONTENT,
//            ]
//        );
//
//        $this->add_control(
//            'show_load_more',
//            [
//                'label'     => __('Show load more', 'erios-core'),
//                'type'      => Controls_Manager::SWITCHER,
//                'label_off' => __('Off', 'erios-core'),
//                'label_on'  => __('On', 'erios-core'),
//            ]
//        );
//
//        $this->add_control(
//            'button_type',
//            [
//                'label'        => __('Type', 'erios-core'),
//                'type'         => Controls_Manager::SELECT,
//                'default'      => '',
//                'options'      => [
//                    ''        => __('Default', 'erios-core'),
//                    'info'    => __('Info', 'erios-core'),
//                    'success' => __('Success', 'erios-core'),
//                    'warning' => __('Warning', 'erios-core'),
//                    'danger'  => __('Danger', 'erios-core'),
//                ],
//                'prefix_class' => 'elementor-button-',
//                'condition'    => [
//                    'show_load_more' => 'yes',
//                ]
//            ]
//        );
//
//        $this->add_control(
//            'text',
//            [
//                'label'       => __('Text', 'erios-core'),
//                'type'        => Controls_Manager::TEXT,
//                'dynamic'     => [
//                    'active' => true,
//                ],
//                'default'     => __('View more', 'erios-core'),
//                'placeholder' => __('Enter text here', 'erios-core'),
//                'condition'   => [
//                    'show_load_more' => 'yes',
//                ]
//            ]
//        );
//
//        $this->add_responsive_control(
//            'align',
//            [
//                'label'        => __('Alignment', 'erios-core'),
//                'type'         => Controls_Manager::CHOOSE,
//                'options'      => [
//                    'left'    => [
//                        'title' => __('Left', 'erios-core'),
//                        'icon'  => 'eicon-h-align-left',
//                    ],
//                    'center'  => [
//                        'title' => __('Center', 'erios-core'),
//                        'icon'  => 'eicon-h-align-center',
//                    ],
//                    'right'   => [
//                        'title' => __('Right', 'erios-core'),
//                        'icon'  => 'eicon-h-align-right',
//                    ],
//                    'justify' => [
//                        'title' => __('Justified', 'erios-core'),
//                        'icon'  => 'eicon-text-align-justify',
//                    ],
//                ],
//                'prefix_class' => 'elementor%s-align-',
//                'default'      => '',
//                'condition'    => [
//                    'show_load_more' => 'yes',
//                ]
//            ]
//        );
//
//        $this->add_control(
//            'size',
//            [
//                'label'     => __('Size', 'erios-core'),
//                'type'      => Controls_Manager::SELECT,
//                'default'   => 'sm',
//                'options'   => self::get_button_sizes(),
//                'condition' => [
//                    'show_load_more' => 'yes',
//                ]
//            ]
//        );
//
//        $this->end_controls_section();

        $this->start_controls_section(
            'section_query',
            [
                'label' => __('Query', 'erios-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'advanced',
            [
                'label' => __('Advanced', 'erios-core'),
                'type' => Controls_Manager::HEADING,
            ]
        );

        $this->add_control(
            'categories',
            [
                'label' => __('Categories', 'erios-core'),
                'type' => Controls_Manager::SELECT2,
                'options' => $this->get_room_categories(),
                'multiple' => true,
            ]
        );

        $this->add_control(
            'orderby',
            [
                'label' => __('Order By', 'erios-core'),
                'type' => Controls_Manager::SELECT,
                'default' => 'date',
                'options' => [
                    'date' => __('Date', 'erios-core'),
                    'title' => __('Title', 'erios-core'),
                    'menu_order' => __('Menu Order', 'erios-core'),
                    'rand' => __('Random', 'erios-core'),
                    'ID' => __('ID', 'erios-core')
                ],
            ]
        );

        $this->add_control(
            'order',
            [
                'label' => __('Order', 'erios-core'),
                'type' => Controls_Manager::SELECT,
                'default' => 'desc',
                'options' => [
                    'asc' => __('ASC', 'erios-core'),
                    'desc' => __('DESC', 'erios-core'),
                ],
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'section_design_filter',
            [
                'label' => __('Filter Bar', 'erios-core'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'show_filter_bar' => 'yes',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'typography_filter',
                'selector' => '{{WRAPPER}} .elementor-room__filter',
            ]
        );

        $this->start_controls_tabs('tabs_wrapper_style');

        $this->start_controls_tab(
            'tab_filter_normal',
            [
                'label' => __('Normal', 'erios-core'),
            ]
        );
        $this->add_control(
            'color_filter',
            [
                'label' => __('Color', 'erios-core'),
                'type' => Controls_Manager::COLOR,
                'default' => '#777777',
                'selectors' => [
                    '{{WRAPPER}} .elementor-room__filter' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'background_filter',
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .elementor-room__filter',
            ]
        );
        $this->end_controls_tab();

        $this->start_controls_tab(
            'tab_filter_hover',
            [
                'label' => __('Hover', 'erios-core'),
            ]
        );
        $this->add_control(
            'color_filter_active',
            [
                'label' => __('Active Color', 'erios-core'),
                'type' => Controls_Manager::COLOR,
                'default' => '#222222',
                'selectors' => [
                    '{{WRAPPER}} .elementor-room__filter.elementor-active,{{WRAPPER}} .elementor-room__filter:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'background_filter_hover',
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .elementor-room__filter.elementor-active,{{WRAPPER}} .elementor-room__filter:hover',
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->add_control(
            'filter_item_spacing',
            [
                'label' => __('Space Between', 'erios-core'),
                'type' => Controls_Manager::SLIDER,
                'default' => [
                    'size' => 5,
                ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .elementor-room__filter:not(:last-child)' => 'margin-right: calc({{SIZE}}{{UNIT}}/2)',
                    '{{WRAPPER}} .elementor-room__filter:not(:first-child)' => 'margin-left: calc({{SIZE}}{{UNIT}}/2)',
                ],
                'separator' => 'before'
            ]
        );

        $this->add_responsive_control(
            'filter_spacing',
            [
                'label' => __('Spacing', 'erios-core'),
                'type' => Controls_Manager::SLIDER,
                'default' => [
                    'size' => 50,
                ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .elementor-room__filters' => 'margin-bottom: {{SIZE}}{{UNIT}}',
                ],
            ]
        );
        $this->add_responsive_control(
            'filter_padding',
            [
                'label' => __('Filter Padding', 'erios-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .elementor-room__filters' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'filter_align',
            [
                'label' => __('Alignment', 'erios-core'),
                'type' => Controls_Manager::CHOOSE,
                'default' => 'top',
                'options' => [
                    'left' => [
                        'title' => __('Left', 'erios-core'),
                        'icon' => 'eicon-h-align-left',
                    ],
                    'center' => [
                        'title' => __('Center', 'erios-core'),
                        'icon' => 'eicon-h-align-center',
                    ],
                    'right' => [
                        'title' => __('Right', 'erios-core'),
                        'icon' => 'eicon-h-align-right',
                    ]
                ],
                'toggle' => false,
                'prefix_class' => 'elementor-filter-',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_content_style',
            [
                'label' => __('Content', 'erios-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );


        $this->add_control(
            'content_color',
            [
                'label' => __('Color', 'erios-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}}  .room-inner' => 'color: {{VALUE}};',
                    '{{WRAPPER}}  .entry-content' => 'color: {{VALUE}};',
                    '{{WRAPPER}}  .entry-title a ' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'button_ajax_background',
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}}.elementor-widget-opal-room .room-inner .room-content',
            ]
        );
        $this->add_responsive_control(
            'content_padding',
            [
                'label' => __('Padding', 'erios-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .room-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'box_shadow',
                'selector' => '{{WRAPPER}} .column-item .room-inner',
            ]
        );
        $this->add_control(
            'Title_heading',
            [
                'label' => __('Title', 'erios-core'),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .entry-title',
                'label' => __('Title Typo', 'erios-core'),
            ]
        );
        $this->add_responsive_control(
            'title_margin',
            [
                'label' => __('Margin', 'erios-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .room-content' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'room_types',
            [
                'label' => __('Types', 'erios-core'),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'types_typography',
                'selector' => '{{WRAPPER}} .room-types a',
                'label' => __('Title Typo', 'erios-core'),
            ]
        );
        $this->add_responsive_control(
            'types_margin',
            [
                'label' => __('Margin', 'erios-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .room-types' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'room_description',
            [
                'label' => __('Description', 'erios-core'),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'description_typography',
                'selector' => '{{WRAPPER}} .room-description',
                'label' => __('Title Typo', 'erios-core'),
            ]
        );
        $this->add_responsive_control(
            'description_margin',
            [
                'label' => __('Margin', 'erios-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .room-description' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'room_price',
            [
                'label' => __('Price', 'erios-core'),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'price_typography',
                'selector' => '{{WRAPPER}} .room-inner .price',
                'label' => __('Title Typo', 'erios-core'),
            ]
        );
        $this->add_responsive_control(
            'room_price_number',
            [
                'label'      => esc_html__('Price Number', 'erios-core'),
                'type'       => Controls_Manager::SLIDER,
                'range'      => [
                    'px' => [
                        'min' => 10,
                        'max' => 50,
                    ],
                ],
                'size_units' => ['px'],
                'selectors'  => [
                    '{{WRAPPER}} .room-inner .price .price_value' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'group_border',
                'placeholder' => '1px',
                'default' => '1px',
                'selector' => '{{WRAPPER}} .room-group-style-3',
            ]
        );
        $this->add_responsive_control(
            'price_margin',
            [
                'label' => __('Margin', 'erios-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .room-inner .price' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->start_controls_tabs('group_colors');

        $this->start_controls_tab(
            'color_normal',
            [
                'label' => __('Normal', 'erios-core'),
            ]
        );
        $this->add_control(
            'title_color',
            [
                'label' => __('Title Color', 'erios-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}}  .entry-title a' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'types_color',
            [
                'label' => __('Types Color', 'erios-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .room-types a' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .room-types a:before' => 'border-color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'description_color',
            [
                'label' => __('Description Color', 'erios-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .room-description' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'price_color',
            [
                'label' => __('Price Color', 'erios-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .price' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'price_number_color',
            [
                'label' => __('Price Number', 'erios-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .price .price_value' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'button_color',
            [
                'label' => __('Button Color', 'erios-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .room-read-link' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'icon_color',
            [
                'label' => __('Button Icon', 'erios-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .room-read-link i' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'group_color_hover',
            [
                'label' => __('Hover', 'erios-core'),
            ]
        );

        $this->add_control(
            'title_hover_color',
            [
                'label' => __('Title Color', 'erios-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .entry-title a:hover' => 'color: {{VALUE}};',
                    '{{WRAPPER}}  .room-inner a:hover ' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'types_color_hover',
            [
                'label' => __('Types Color', 'erios-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .room-types a:hover' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'button_hover_color',
            [
                'label' => __('Button Color', 'erios-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .room-read-link:hover' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'icon_hover_color',
            [
                'label' => __('Button Icon', 'erios-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .room-read-link:hover i' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();

        $this->start_controls_section(
            'section_image_style',
            [
                'label' => __('Image', 'erios-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'image-height',
            [
                'label'      => esc_html__('Height', 'erios-core'),
                'type'       => Controls_Manager::SLIDER,
                'range'      => [
                    'px' => [
                        'min' => 100,
                        'max' => 1000,
                    ],
                    'vh' => [
                        'min' => 10,
                        'max' => 100,
                    ],
                ],
                'size_units' => ['px', 'vh'],
                'selectors'  => [
                    '{{WRAPPER}} .room-inner .room-post-thumbnail' => 'height: {{SIZE}}{{UNIT}}; object-fit: cover;',
                    '{{WRAPPER}} .room-inner .room-post-thumbnail img' => 'height: {{SIZE}}{{UNIT}}; object-fit: cover;',
                ],
            ]
        );

        $this->end_controls_section();

        // Carousel Option
        $this->add_control_carousel(
            [
                'show_filter_bar!' => 'yes'
            ]
        );
    }

    public function query_posts()
    {
        $query_args = [
            'orderby' => $this->get_settings_for_display('orderby'),
            'order' => $this->get_settings_for_display('order'),
            'ignore_sticky_posts' => 1,
            'post_status' => 'publish', // Hide drafts/private posts for admins
            'post_type' => 'hb_room',
            'posts_per_page' => $this->get_settings_for_display('posts_per_page')
        ];

        if (!empty($this->get_settings_for_display('categories'))) {
            $query_args['tax_query'] = [
                [
                    'taxonomy' => 'hb_room_type',
                    'field' => 'slug',
                    'terms' => $this->get_settings_for_display('categories'),
                ]
            ];
        }
        return new WP_Query($query_args);
    }

    public function render()
    {
        $settings = $this->get_settings_for_display();
        $wp_query = $this->query_posts();

        global $post;

        if (!$wp_query->found_posts) {
            return;
        }

        $this->add_render_attribute('wrapper', 'class', 'elementor-post-wrapper');


        $this->add_render_attribute('wrapper', 'id', 'isotope-' . $this->get_id());
        $this->add_render_attribute('row', 'class', 'isotope-grid');
        $this->add_render_attribute('row', 'class', 'row');
        $this->add_render_attribute('row', 'class', 'tp-hotel-booking');

        $this->add_render_attribute('row', 'class', $settings['style']);


        if ($settings['enable_carousel'] === 'yes') {
            $this->add_render_attribute('row', 'class', 'owl-carousel owl-theme');
            $carousel_settings = array(
                'navigation' => $settings['navigation'],
                'autoplayHoverPause' => $settings['pause_on_hover'] === 'yes' ? true : false,
                'autoplay' => $settings['autoplay'] === 'yes' ? true : false,
                'autoplayTimeout' => $settings['autoplay_speed'],
                'items' => !empty($settings['columns']) ? $settings['columns'] : 2,
                'items_tablet' => !empty($settings['columns_tablet']) ? $settings['columns_tablet'] : 1,
                'items_mobile' => !empty($settings['columns_mobile']) ? $settings['columns_mobile'] : 1,
                'loop' => $settings['infinite'] === 'yes' ? true : false,
                'center' => $settings['center_mode'] === 'yes' ? true : false,
                'stagePadding' => $settings['center_padding'],
                'stagePadding_tablet' => !empty($settings['center_padding_tablet']) ? $settings['center_padding_tablet'] : $settings['center_padding'],
                'stagePadding_mobile' => !empty($settings['center_padding_mobile']) ? $settings['center_padding_mobile'] : 0,

                'margin' => $settings['margin_owl'],
                'margin_tablet' => $settings['margin_owl_tablet'] ? $settings['margin_owl_tablet'] : $settings['margin_owl'],
                'margin_mobile' => $settings['margin_owl_mobile'] ? $settings['margin_owl_mobile'] : 0,

            );
            $this->add_render_attribute('row', 'data-settings', wp_json_encode($carousel_settings));
        } else {

            if ($settings['style'] == 'room-style-1' || $settings['style'] == 'room-style-6' || $settings['style'] == 'room-style-5' || $settings['style'] == 'room-style-4' || $settings['style'] == 'room-style-3') {
                $this->add_render_attribute('row', 'data-elementor-columns', $settings['columns']);
                $this->add_render_attribute('row', 'data-elementor-columns-tablet', $settings['columns_tablet']);
                $this->add_render_attribute('row', 'data-elementor-columns-mobile', $settings['columns_mobile']);
            }
            if ($settings['style'] == 'room-style-2') {
                $this->add_render_attribute('row', 'data-elementor-columns', 4);
                $this->add_render_attribute('row', 'data-elementor-columns-tablet', 2);
                $this->add_render_attribute('row', 'data-elementor-columns-mobile', 1);
            }
        }

        if ($this->get_settings('show_filter_bar')) {
            $this->render_filter_menu($settings['categories']);
        }

        ?>
        <div <?php echo $this->get_render_attribute_string('wrapper'); ?>>
            <div <?php echo $this->get_render_attribute_string('row') ?>>

                <?php

                while ($wp_query->have_posts()) {
                    $wp_query->the_post();
                    $item_classes = '__all ';
                    $item_cats = get_the_terms($wp_query->post->ID, 'hb_room_type');
                    foreach ((array)$item_cats as $item_cat) {
                        if (!empty($item_cats) && !is_wp_error($item_cats)) {
                            $item_classes .= $item_cat->slug . ' ';
                        }
                    }
                    echo '<div class="column-item room-entries ' . esc_attr($item_classes) . '">';
                    get_template_part('template-parts/room/item', $settings['style']);
                    echo '</div>';
                }
                ?>
            </div>
        </div>
        <?php
        wp_reset_postdata();
    }


    protected function render_filter_menu($categories)
    {
        $terms = [];

        if ($categories && !empty($categories)) {
            foreach ($categories as $category) {
                $term = get_term_by('slug', $category, 'hb_room_type');

                if ($term->count != 0) {
                    $terms[$term->slug] = $term->name;
                }

                if ($term->parent == 0) {
                    $chirlds = get_term_children($term->term_id, 'hb_room_type');

                    if (!is_wp_error($chirlds)) {
                        foreach ($chirlds as $chirld) {
                            $category = get_term_by('term_id', $chirld, 'hb_room_type');
                            $terms[$category->slug] = $category->name;
                        }

                    }
                }
            }
        } else {
            $terms = $this->get_room_categories();
        }

        ?>
        <ul class="elementor-room__filters" data-related="isotope-<?php echo esc_attr($this->get_id()); ?>">
            <li class="elementor-room__filter elementor-active"
                data-filter=".__all"><?php echo __('All', 'erios-core'); ?></li>
            <?php foreach ($terms as $key => $term) { ?>
                <li class="elementor-room__filter"
                    data-filter=".<?php echo esc_attr($key); ?>"><?php echo $term; ?></li>
            <?php } ?>
        </ul>
        <?php
    }

    protected function get_room_categories()
    {
        $categories = get_terms(array(
                'taxonomy' => 'hb_room_type',
                'hide_empty' => false,
            )
        );
        $results = array();
        if (!is_wp_error($categories)) {
            foreach ($categories as $category) {
                $results[$category->slug] = $category->name;
            }
        }
        return $results;

    }

    private function get_template_post_type()
    {
        $folderes = glob(get_template_directory() . '/template-parts/room/item-*');

        $output = array();

        foreach ($folderes as $folder) {
            $folder = str_replace("item-", '', str_replace('.php', '', wp_basename($folder)));
            $value = str_replace('_', ' ', str_replace('-', ' ', ucfirst($folder)));
            $output[$folder] = $value;
        }

        return $output;
    }
}

$widgets_manager->register(new OSF_Elementor_Room());