<?php

use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Widget_Base;

if (!defined('ABSPATH')) {
    exit;
} // Exit if accessed directly

class OSF_Elementor_Views_Derection extends Widget_Base
{


    public function get_name()
    {
        return 'opal-views-derection';
    }

    public function get_title()
    {
        return __('Opal Views Direction', 'erios-core');
    }

    public function get_categories()
    {
        return ['opal-addons'];
    }


    protected function register_controls()
    {
        $this->start_controls_section('view_layout',
            [
                'label' => __('Layout', 'erios-core')
            ]);

        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'thumbnail',
                'default' => 'full',
                'separator' => 'none',
            ]
        );

        $this->start_controls_tabs('views_image');
        $this->start_controls_tab('view_n',
            [
                'label' => __('Nouth', 'erios-core')
            ]);
        $this->add_control(
            'image_n',
            [
                'label' => __('Choose Image', 'erios-core'),
                'type' => Controls_Manager::MEDIA,
                'dynamic' => [
                    'active' => true,
                ],
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );
        $this->end_controls_tab();
        $this->start_controls_tab('view_e',
            [
                'label' => __('East', 'erios-core')
            ]);
        $this->add_control(
            'image_e',
            [
                'label' => __('Choose Image', 'erios-core'),
                'type' => Controls_Manager::MEDIA,
                'dynamic' => [
                    'active' => true,
                ],
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );
        $this->end_controls_tab();
        $this->start_controls_tab('view_s',
            [
                'label' => __('South', 'erios-core')
            ]);
        $this->add_control(
            'image_s',
            [
                'label' => __('Choose Image', 'erios-core'),
                'type' => Controls_Manager::MEDIA,
                'dynamic' => [
                    'active' => true,
                ],
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );
        $this->end_controls_tab();

        $this->start_controls_tab('view_w',
            [
                'label' => __('West', 'erios-core')
            ]);
        $this->add_control(
            'image_w',
            [
                'label' => __('Choose Image', 'erios-core'),
                'type' => Controls_Manager::MEDIA,
                'dynamic' => [
                    'active' => true,
                ],
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );
        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();
    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();

        ?>
        <div class="owl-carousel">
            <div class="item" data-hash="<?php echo 'nouth-' . $this->get_id(); ?>">
                <?php if ($settings['image_n']['url']): echo Group_Control_Image_Size::get_attachment_image_html($settings, 'thumbnail', 'image_n'); endif; ?>
            </div>
            <div class="item" data-hash="<?php echo 'east-' . $this->get_id(); ?>">
                <?php if ($settings['image_e']['url']): echo Group_Control_Image_Size::get_attachment_image_html($settings, 'thumbnail', 'image_e'); endif; ?>
            </div>
            <div class="item" data-hash="<?php echo 'south-' . $this->get_id(); ?>">
                <?php if ($settings['image_s']['url']): echo Group_Control_Image_Size::get_attachment_image_html($settings, 'thumbnail', 'image_s'); endif; ?>
            </div>
            <div class="item" data-hash="<?php echo 'west-' . $this->get_id(); ?>">
                <?php if ($settings['image_w']['url']): echo Group_Control_Image_Size::get_attachment_image_html($settings, 'thumbnail', 'image_w'); endif; ?>
            </div>
        </div>
        <div class="views-derection-control">
            <div class="views-derection-indicator"></div>
            <a class="views-derection-link n <?php echo 'nouth-' . $this->get_id(); ?>"
               href="<?php echo '#nouth-' . $this->get_id(); ?>" data-derection="n"><?php echo esc_html__('N', 'erios-core'); ?></a>
            <a class="views-derection-link e <?php echo 'east-' . $this->get_id(); ?>"
               href="<?php echo '#east-' . $this->get_id(); ?>" data-derection="e"><?php echo esc_html__('E', 'erios-core'); ?></a>
            <a class="views-derection-link s <?php echo 'south-' . $this->get_id(); ?>"
               href="<?php echo '#south-' . $this->get_id(); ?>" data-derection="s"><?php echo esc_html__('S', 'erios-core'); ?></a>
            <a class="views-derection-link w <?php echo 'west-' . $this->get_id(); ?>"
               href="<?php echo '#west-' . $this->get_id(); ?>" data-derection="w"><?php echo esc_html__('W', 'erios-core'); ?></a>
        </div>
        <?php

    }
}

$widgets_manager->register(new OSF_Elementor_Views_Derection());

